@@ -2,21 +2,20 @@
  * dtbl-prepend.cc: Part of GNU CSSC.
  * 
  * 
- *    Copyright (C) 1997,1999 Free Software Foundation, Inc. 
+ *    Copyright (C) 1997,1999,2007 Free Software Foundation, Inc. 
  * 
- *    This program is free software; you can redistribute it and/or modify
+ *    This program is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
- *    the Free Software Foundation; either version 2 of the License, or
+ *    the Free Software Foundation, either version 3 of the License, or
  *    (at your option) any later version.
- * 
+ *    
  *    This program is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *    GNU General Public License for more details.
- * 
+ *    
  *    You should have received a copy of the GNU General Public License
- *    along with this program; if not, write to the Free Software
- *    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111, USA.
+ *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
  * CSSC was originally Based on MySC, by Ross Ridge, which was 
  * placed in the Public Domain.
@@ -30,7 +29,7 @@
 #include "delta-table.h"
 
 #ifdef CONFIG_SCCS_IDS
-static const char rcs_id[] = "CSSC $Id: dtbl-prepend.cc,v 1.4 2001/09/29 19:39:41 james_youngman Exp $";
+static const char rcs_id[] = "CSSC $Id: dtbl-prepend.cc,v 1.7 2007/12/17 21:59:48 jay Exp $";
 #endif
 
 
@@ -50,3 +49,9 @@ cssc_delta_table::prepend(const delta &it)
 }
 
 
+// Explicit template instantiations.
+template mylist<delta>& operator+=<delta>(mylist<delta>&, mylist<delta> const&);
+
+/* Local variables: */
+/* mode: c++ */
+/* End: */
