@@ -2,7 +2,7 @@
  * sccsfile.cc: Part of GNU CSSC.
  * 
  * 
- *    Copyright (C) 1997,1998,1999,2001,2003,2004,2007 Free Software Foundation, Inc. 
+ *    Copyright (C) 1997,1998,1999,2001,2003,2004,2007,2008 Free Software Foundation, Inc. 
  * 
  *    This program is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@
 
 
 #ifdef CONFIG_SCCS_IDS
-static const char rcs_id[] = "CSSC $Id: sccsfile.cc,v 1.64 2007/12/17 23:10:17 jay Exp $";
+static const char rcs_id[] = "CSSC $Id: sccsfile.cc,v 1.67 2008/01/06 19:42:23 jay Exp $";
 #endif
 
 #if defined(HAVE_FILENO) && defined(HAVE_FSTAT)
@@ -681,7 +681,7 @@ sccs_file::get_module_name() const
    locked if it isn't only being read.  */
 
 sccs_file::sccs_file(sccs_name &n, enum _mode m)
-  : name(n), mode(m), lineno(0), xfile_created(false), is_bk_file(false), f(0)
+  : name(n), f(0), mode(m), lineno(0), xfile_created(false), is_bk_file(false)
 {
   delta_table = new cssc_delta_table;
   plinebuf     = new cssc_linebuf;
@@ -698,7 +698,7 @@ sccs_file::sccs_file(sccs_name &n, enum _mode m)
   flags.branch = 0;
   flags.floor = 0;
   flags.ceiling = 0;
-  flags.default_sid = NULL;	// (XXX: correct use of NULL?) 
+  flags.default_sid = sid::null_sid();
   flags.null_deltas = 0;
   flags.joint_edit = 0;
   flags.all_locked = 0;
@@ -710,6 +710,8 @@ sccs_file::sccs_file(sccs_name &n, enum _mode m)
   flags.reserved = 0;
   flags.user_def = 0;
   
+  ASSERT(!flags.default_sid.valid());
+
   if (mode != READ)
     {
       if (name.lock())
