@@ -2,7 +2,7 @@
  * sf-admin.cc: Part of GNU CSSC.
  * 
  * 
- *    Copyright (C) 1997,1998,1999,2001,2004,2007 Free Software Foundation, Inc. 
+ *    Copyright (C) 1997,1998,1999,2001,2004,2007,2008 Free Software Foundation, Inc. 
  * 
  *    This program is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@
 
 
 #ifdef CONFIG_SCCS_IDS
-static const char rcs_id[] = "CSSC $Id: sf-admin.cc,v 1.36 2007/12/17 21:59:51 jay Exp $";
+static const char rcs_id[] = "CSSC $Id: sf-admin.cc,v 1.39 2008/01/06 19:42:23 jay Exp $";
 #endif
 
 
@@ -261,7 +261,8 @@ sccs_file::admin(const char *file_comment,
 	  
 	  
 	case 'd':
-	  flags.default_sid = NULL; // (XXX: correct use of NULL?) 
+	  flags.default_sid = sid::null_sid();
+	  ASSERT(!flags.default_sid.valid());
 	  break;
 	  
 	case 'i':
@@ -280,7 +281,18 @@ sccs_file::admin(const char *file_comment,
 	    }
 	  else
 	    {
-	      flags.locked.remove(release_list(s));
+	      if (flags.all_locked)
+		{
+		  errormsg("Unlocking just release %s of %s is not possible, "
+			   "since all releases are locked.  "
+			   "Use admin -dla to unlock all releases.",
+			   s, name.c_str());
+		  return false;
+		}
+	      else
+		{
+		  flags.locked.remove(release_list(s));
+		}
 	    }
 	  break;
 	  
