@@ -3,7 +3,7 @@
  * 
  * 
  *    Copyright (C) 1997,1998,2001,2002,
- *                  2004,2007 Free Software Foundation, Inc. 
+ *                  2004,2007,2008 Free Software Foundation, Inc. 
  * 
  *    This program is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 
 
 #ifdef CONFIG_SCCS_IDS
-static const char rcs_id[] = "CSSC $Id: sf-val.cc,v 1.9 2007/12/17 21:59:51 jay Exp $";
+static const char rcs_id[] = "CSSC $Id: sf-val.cc,v 1.13 2008/01/07 01:09:29 jay Exp $";
 #endif
 
 const mystring
@@ -89,26 +89,62 @@ sccs_file::validate_seq_lists(const delta_iterator& d) const
 bool 
 sccs_file::validate_isomorphism() const
 {
-  // First decide for each delta if it is a branch point or not.
-  // then decide for each delta if it is on the branch or on the trunk.
-  //
-  // A delta is a branch point if more than one delta in the 
-  // delta table references it as a predecessor.
-  //
-  // A delta is on a branch if it has an ancestor which is a branch point,
-  // UNLESS it was the next revision on the trunk.  How to determine this?
-  //
-  // All branch deltas must have 4-component SIDs.
-  // All trunk deltas must have 2-component SIDs.
-  //
+  // SCCS files exist where a delta on the trunk has as a parent
+  // a delta which is itself not on the trunk.  This makes it 
+  // hard to verify that the SID values are consistent with the 
+  // tree of seqno values.
 
-  // TODO: write this later.
-  return true;
+  int *trunk_child_count = new int[1+delta_table->highest_seqno()];
+  seq_no seq;
+
+  
+  // Count how many children on the trunk each delta has.
+  for (seq=0; seq<=delta_table->highest_seqno(); ++seq)
+    {
+      trunk_child_count[seq] = 0;
+      if (seq)
+	{
+	  if (delta_table->delta_at_seq_exists(seq)
+	      && !delta_table->delta_at_seq(seq).removed())
+	    
+	    {
+	      const delta & d = delta_table->delta_at_seq(seq);
+	      if (d.id.on_trunk())
+		{
+		  ++trunk_child_count[d.prev_seq];
+		}
+	    }
+	}
+    }
+  
+
+  bool problem = false;
+  for (seq=1; seq<=delta_table->highest_seqno(); ++seq)
+    {
+      if (delta_table->delta_at_seq_exists(seq)
+	  && !delta_table->delta_at_seq(seq).removed())
+	{
+	  if (trunk_child_count[seq] > 1)
+	    {
+	      const delta & d = delta_table->delta_at_seq(seq);
+	      const char *sz_sid = d.id.as_string().c_str();
+	      warning("%s: SID %s has %d children on the trunk",
+		      name.c_str(), sz_sid,
+		      trunk_child_count[seq]);
+	      problem = true;
+	      
+	    }
+	}
+    }
+
+  return !problem;
 }
 
 static bool
 validate_substituted_flags_list(const mylist<char> entries)
 {
+  // TODO: write this later.
+  return true;
 }
 
 
@@ -184,7 +220,6 @@ sccs_file::validate() const
 	  errormsg("%s: SID %s: empty username", name.c_str(), sz_sid);
 	  retval = false;
 	}
-      
       else if (iter->user.find_last_of(':') != mystring::npos)
 	{
 	  errormsg("%s: SID %s: invalid username '%s'",
@@ -210,7 +245,7 @@ sccs_file::validate() const
       if (seen_ever[s - 1] > 1)
 	{
 	  errormsg("%s: seqno %d appears more than once (%d times)",
-		   name.c_str(), (int)s, seen_ever[iter->seq - 1]);
+		   name.c_str(), (int)s, seen_ever[s - 1]);
 	  retval = false;		// seqno appears more than once.
 	}
 
@@ -306,6 +341,34 @@ sccs_file::validate() const
 	}
     }
 
+  if (flags.floor > delta_table->highest_release())
+    {
+      warning("%s has a release floor of %d but the highest actual release "
+	      "in the file is %d",
+	      name.c_str(), (short)flags.floor,
+	      delta_table->highest_release().as_string().c_str());
+    }
+
+  if (!flags.default_sid.is_null())
+    {
+      const delta* pd = delta_table->find_any(flags.default_sid);
+      if (pd)
+	{
+	  if (pd->removed())
+	    {
+	      warning("%s has a default SID of %s, but that SID has "
+		      "been removed",
+		      name.c_str(), flags.default_sid.as_string().c_str());
+	    }
+	}
+      else
+	{
+	  warning("%s has a default SID of %s, but that SID is not present",
+		  name.c_str(), flags.default_sid.as_string().c_str());	      
+	}
+    }
+  
+
   
   // TODO: check for unknown flags
   // TODO: check for boolean flags with non-numeric value.
