@@ -24,7 +24,7 @@
  * INSTALL files for details of the specific configuration options
  * which are possible.
  *
- * $Id: showconfig.cc,v 1.6 2007/12/17 21:59:52 jay Exp $
+ * $Id: showconfig.cc,v 1.7 2008/01/18 10:00:58 jay Exp $
  */
 #include "cssc.h"
 
@@ -38,11 +38,11 @@
 
 
 static const char * copyright_explanation = 
-"Copyright (C) 1997-2002 Free Software Foundation, Inc.\n"
+"Copyright (C) 1997-2008 Free Software Foundation, Inc.\n"
 "\n"
-"This program is free software; you can redistribute it and/or modify\n"
+"This program is free software: you can redistribute it and/or modify\n"
 "it under the terms of the GNU General Public License as published by\n"
-"the Free Software Foundation; either version 2 of the License, or\n"
+"the Free Software Foundation, either version 3 of the License, or\n"
 "(at your option) any later version.\n"
 "\n"
 "This program is distributed in the hope that it will be useful,\n"
@@ -51,10 +51,7 @@ static const char * copyright_explanation =
 "GNU General Public License for more details.\n"
 "\n"
 "You should have received a copy of the GNU General Public License\n"
-"along with this program in the file COPYING; if not, write to the\n"
-"Free Software Foundation, Inc.,\n"
-"51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.\n";
-
+"along with this program.  If not, see <http://www.gnu.org/licenses/>.\n";
 
 void show_copyright(void)
 {
@@ -96,8 +93,7 @@ static void show_system_line_max(void)
 #ifdef HAVE_GNU_DIFF
       fprintf(stderr,
 	      "\nWhen this version of CSSC was compiled, %s was GNU diff, "
-	      "which has no upper limit\n"
-	      "on line lengths.\n",
+	      "which has no upper limit on line lengths.\n",
 	      (CONFIG_DIFF_COMMAND));
 #endif
       
