@@ -2,7 +2,7 @@
  * sid.cc: Part of GNU CSSC.
  * 
  * 
- *    Copyright (C) 1997,1999,2007 Free Software Foundation, Inc. 
+ *    Copyright (C) 1997,1999,2007,2008 Free Software Foundation, Inc. 
  * 
  *    This program is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #include <ctype.h>
 
 #ifdef CONFIG_SCCS_IDS
-static const char rcs_id[] = "CSSC $Id: sid.cc,v 1.19 2007/12/17 21:59:52 jay Exp $";
+static const char rcs_id[] = "CSSC $Id: sid.cc,v 1.21 2008/01/06 19:42:24 jay Exp $";
 #endif
 
 
@@ -103,6 +103,12 @@ release::release(const char *s) {
 	}
 }
 
+sid 
+sid::null_sid() 
+{
+  return sid(0, 0, 0, 0);
+}
+
 sid::sid(const char *s) {
 	if (s == NULL) {
 		sequence = branch = level = rel = 0;
