@@ -21,7 +21,7 @@
  * Not all systems have uudecode.  In particular, Cygwin lacks it.
  * Hence we provide our own. 
  *
- * $Id: uu_decode.c,v 1.5 2007/12/17 21:59:53 jay Exp $
+ * $Id: uu_decode.c,v 1.6 2007/12/19 00:21:14 jay Exp $
  */
 
 /*
@@ -40,6 +40,10 @@
 #include <stdlib.h>
 #include <errno.h>
 
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+
 
 
 #define UUDEC(c)        (((c) - 040) & 077)
@@ -167,7 +171,9 @@ test_decode(const char *arg)
   char inbuf[80], outbuf[80];
   int mode, nf, expect_end_line;
   FILE *fp_output;
-  
+
+  (void) arg;
+
   if ( 0 != fgets(inbuf, sizeof(inbuf)-1, stdin))
     {
       nf = sscanf(inbuf, "begin %o %[^\n]", &mode, outbuf);
@@ -239,6 +245,8 @@ int test_all(const char *arg)
   long l0, l1, l2, lo;
   long i;
 
+  (void) arg;
+
   /* i only has to hold a 24-bit value. */
   const long maxval = 0xff | (0xff<<8) | (0xff<<16);
   const double dmaxval = maxval;
