@@ -2,7 +2,7 @@
  * unget.cc: Part of GNU CSSC.
  * 
  * 
- *    Copyright (C) 1997,1998,1999,2001,2007 Free Software Foundation, Inc. 
+ *    Copyright (C) 1997,1998,1999,2001,2007,2008 Free Software Foundation, Inc. 
  * 
  *    This program is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 #include "except.h"
 
 
-const char main_rcs_id[] = "CSSC $Id: unget.cc,v 1.25 2007/12/17 21:59:52 jay Exp $";
+const char main_rcs_id[] = "CSSC $Id: unget.cc,v 1.27 2008/01/06 19:42:24 jay Exp $";
 
 void
 usage() {
@@ -47,7 +47,7 @@ main(int argc, char **argv)
 {
   Cleaner arbitrary_name;
   int c;
-  sid rid = NULL;		// (XXX: correct use of NULL?) 
+  sid rid(sid::null_sid());
   int silent = 0;
   int keep_gfile = 0;
   
@@ -56,6 +56,8 @@ main(int argc, char **argv)
   else
     set_prg_name("unget");
 
+  ASSERT(!rid.valid());
+
   class CSSC_Options opts(argc, argv, "r!snV");
   for (c = opts.next(); c != CSSC_Options::END_OF_ARGUMENTS; c = opts.next())
     {
