@@ -1,7 +1,7 @@
 /*
  * val.cc: Part of GNU CSSC.
  * 
- *    Copyright (C) 1997,1998,2001,2007 Free Software Foundation, Inc. 
+ *    Copyright (C) 1997,1998,2001,2007,2008 Free Software Foundation, Inc. 
  * 
  *    This program is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "except.h"
 #include "valcodes.h"
 
-const char main_rcs_id[] = "$Id: val.cc,v 1.11 2007/12/17 21:59:52 jay Exp $";
+const char main_rcs_id[] = "$Id: val.cc,v 1.13 2008/01/06 19:42:24 jay Exp $";
 
 /* Prints a list of included or excluded SIDs. */
 
@@ -62,13 +62,14 @@ main(int argc, char **argv)
   bool had_r_option = false;
   int c;
   const char *req_sid_str = NULL;
-  sid rid = NULL;		// (XXX: correct use of NULL?) 
+  sid rid(sid::null_sid());
   
   if (argc > 0)
       set_prg_name(argv[0]);
   else
     set_prg_name("val");
 
+  ASSERT(!rid.valid());
 
   class CSSC_Options opts(argc, argv, "sV!m!r!y!", 0);
   for(c = opts.next();
